////////////////////////////////////////////////////////////////////////
// schedule.cpp
// generated with ecppc
//

#include <tnt/ecpp.h>
#include <tnt/httprequest.h>
#include <tnt/httpreply.h>
#include <tnt/httpheader.h>
#include <tnt/http.h>
#include <tnt/data.h>
#include <tnt/componentfactory.h>
#include <cxxtools/log.h>
#include <stdexcept>

log_define("component.schedule")

// <%pre>
#line 1 "schedule.ecpp"


#include <livefeatures.h>
#include <setup.h>
#include <tools.h>
#include <epg_events.h>
#include <recman.h>


#include <vdr/config.h>
using namespace vdrlive;

bool searchNameDesc(RecordingsItemPtr &RecItem, std::list<RecordingsItemPtr> &RecItems, const std::string &Name, const std::string &ShortText, const std::string &Description, long Duration, cGetScraperOverview *scraperOverview) {
  if(RecItems.begin() == RecItems.end() ) return false;  // there are no recordings

// find all recordings with equal name
  RecordingsItemPtr dummy (new RecordingsItemDummy(Name, ShortText, Description, Duration, scraperOverview));
  std::list<RecordingsItemPtr>::iterator recIterLowName = std::lower_bound (RecItems.begin(), RecItems.end(), dummy, RecordingsItemPtrCompare::ByDuplicatesName);
  std::list<RecordingsItemPtr>::iterator recIterUpName  = std::upper_bound (recIterLowName  , RecItems.end(), dummy, RecordingsItemPtrCompare::ByDuplicatesName);
  if ( recIterLowName == recIterUpName ) return false; // there is no recording with this name


// find all recordings with matching short text / description
  std::list<RecordingsItemPtr>::iterator recIterLow = std::lower_bound (recIterLowName, recIterUpName, dummy, RecordingsItemPtrCompare::ByDuplicates);
  std::list<RecordingsItemPtr>::iterator recIterUp = std::upper_bound (recIterLow, recIterUpName, dummy, RecordingsItemPtrCompare::ByDuplicates);

  if(recIterLow != recIterUp) {   // exact match found
    if (RecordingsItemPtrCompare::FindBestMatch(RecItem, recIterLow, recIterUp, dummy) > 0) return true;
    RecItem = *recIterLow;
    return true;
  }
// no exact match found, get recording with most matching characters
  int numEqualCharsLow = 0;
  int numEqualCharsUp  = 0;

  if(recIterLow != recIterLowName) { 
    --recIterLow;
    (*recIterLow)->CompareStD(dummy, &numEqualCharsLow);
  }
  if(recIterUp != recIterUpName)
    (*recIterUp)->CompareStD(dummy, &numEqualCharsUp);

  if ( numEqualCharsLow > numEqualCharsUp ) {
    if( numEqualCharsLow > 5 ) { RecItem = *recIterLow; return true; }
  } else {
    if( numEqualCharsUp  > 5 ) { RecItem = *recIterUp;  return true; }
  }


// no exact match found, get best match
  int num_match_rec = RecordingsItemPtrCompare::FindBestMatch(RecItem, recIterLowName, recIterUpName, dummy);
  if(num_match_rec == 0 || num_match_rec > 5) return false; // no matching lenght or series (too many matching length)
  return true;
}



#line 1 "page_init.eh"

// do not add to Makefile
// and do not write a ecpp comment into this file. It must produce no
// html output not even an empty line.
#include <tnt/savepoint.h>
#include <exception.h>

#line 2 "page_exit.eh"

#include <exception.h>

// </%pre>

namespace
{
class _component_ : public tnt::EcppComponent
{
    _component_& main()  { return *this; }

  protected:
    ~_component_();

  public:
    _component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl);

    unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    class channel_selection_type : public tnt::EcppSubComponent
    {
        _component_& mainComp;
        _component_& main()  { return mainComp; }

      public:
        channel_selection_type(_component_& m, const std::string& name)
          : EcppSubComponent(m, name),
            mainComp(m)
          { }
        unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    };

    class rec_item_file_type : public tnt::EcppSubComponent
    {
        _component_& mainComp;
        _component_& main()  { return mainComp; }

      public:
        rec_item_file_type(_component_& m, const std::string& name)
          : EcppSubComponent(m, name),
            mainComp(m)
          { }
        unsigned operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
    };

    channel_selection_type channel_selection;
    rec_item_file_type rec_item_file;
};

static tnt::EcppComponentFactoryImpl<_component_> Factory("schedule");

static const char* rawData = "\254\001\000\000\255\001\000\000\256\001\000\000\322\001\000\000\335\001\000\000\340\001"
  "\000\000&\002\000\000)\002\000\000A\002\000\000D\002\000\000F\002\000\000\200\002\000\000\271\002\000\000\340\002\000"
  "\000\002\003\000\000$\003\000\000L\003\000\000N\003\000\000k\003\000\000m\003\000\000\225\003\000\000\241\003\000\000"
  "\252\003\000\000\265\003\000\000\353\003\000\000\010\004\000\000\n\004\000\000\020\004\000\000\033\004\000\000C\004"
  "\000\000E\004\000\000t\004\000\000\231\004\000\000\233\004\000\000\243\004\000\000\246\004\000\000\260\004\000\000"
  "\261\004\000\000\262\004\000\000\265\004\000\000\276\004\000\000\301\004\000\000\302\004\000\000\331\004\000\000\360"
  "\004\000\000\n\005\000\000\015\005\000\000\023\005\000\000*\005\000\000\?\005\000\000d\005\000\000\177\005\000\000"
  "\240\005\000\000\246\005\000\000\314\005\000\000\322\005\000\000\331\005\000\000\332\005\000\000\346\005\000\000\000"
  "\006\000\000\001\006\000\000\002\006\000\000_\006\000\000y\006\000\000\216\006\000\000\224\006\000\000\232\006\000"
  "\000\240\006\000\000\356\006\000\0006\007\000\000D\007\000\000E\007\000\000G\007\000\000S\007\000\000\236\007\000\000"
  "\241\007\000\000\273\007\000\000\310\007\000\000\327\007\000\000\342\007\000\000\356\007\000\0009\010\000\000<\010"
  "\000\000C\010\000\000Z\010\000\000t\010\000\000u\010\000\000v\010\000\000|\010\000\000\250\010\000\000\253\010\000"
  "\000\004\t\000\000\034\t\000\000z\t\000\000\222\t\000\000\272\t\000\000\333\t\000\000\360\t\000\000\021\n\000\000\027"
  "\n\000\000*\n\000\000=\n\000\000C\n\000\000D\n\000\000E\n\000\000F\n\000\000G\n\000\000\n\n\n<html>\n\t<head>\n\t\t<t"
  "itle>VDR Live - </title>\n\t\t\n\t\t\n\t</head>\n\t<body onload=\"adjustHeader()\" onresize=\"adjustHeader()\">\n\t\t"
  "\n\t\t\n\t\t<div class=\"inhalt\">\n\t\t\t.\n\t\t<table class=\"listing\" cellspacing=\"0\" cellpadding=\"0\">\n\t\t"
  "\t\t<tr class=\"spacer\">\n\t\t\t\t\t<td colspan=\"5\"/>\n\t\t\t\t</tr>\n\t\t\t\t<tr class=\"head\">\n\t\t\t\t\t<td c"
  "olspan=><div class=\"boxheader\"><div><div></div></div></div></td>\n\t\t\t\t</tr>\n\t\t\t\t<tr>\n\t\t\t\t\t<td class="
  "\"action leftcol \"></td>\n\t\t\t\t\t<td class=\"action \"><a href=\"searchresults.html\?searchplain=\"><img src=\"\""
  " alt=\"\" ></img></a><img src=\"img/transparent.png\" width=\"16\" height=\"16\"></td>\n\t\t\t\t\t<td class=\"action "
  "\"></td>\n<td class=\"\">\n<div class=\"thumb\">\n<a class=\"thumb\" >\n  <img src=\"img/transparent.png\" height=\"1"
  "0px\"\n  <img class=\"thumb\" src=\"/tvscraper/\"\n  title=\n      <br/>SE \n      <br/>\n  \n  />\n</a>\n</div>\n</t"
  "d>\n\n<td class=\"topaligned \"><div class=\"withmargin\"> - <br /></div></td>\n<td class=\" topaligned rightcol \"><"
  "div class=\"more withmargin\">\n  <a >\n     <span class=\"title\"></span><br /><span class=\"short\">&nbsp;</span>\n"
  "  </a></div>\n</td>\n\n\t\t\t\t</tr>\n<tr>\n \n</tr>\n\n\t\t\t</table>\n\t\t</div>\n\t</body>\n</html>\n\n\n<form act"
  "ion=\"schedule.html\" method=\"get\" id=\"channels\">\n   <span>\n     <label for=\"channel\">:&nbsp;<span class=\"bo"
  "ld\"></span></label>\n     \n     \n     \n     \n   </span>\n</form>\n<span class=\"sep\">|</span>\n<a href=\"schedu"
  "le.html\?channel=\">\302\253 Prev</a>\n<span class=\"sep\">|</span>\n<a href=\"schedule.html\?channel=\">Next \302"
  "\273</a>\n\n\n\n<td colspan= style=\"word-wrap: normal;min-width: 10px;max-width: 70px;\" class=\"leftcol \">   </td>"
  "\n<td class=\"action \"> <img src=\"\" alt=\"on_dvd\"  /> </td>\n\n<td colspan= style=\"word-wrap: normal;min-width: "
  "10px;max-width: 70px;\" class=\"leftcol \">  </td>\n\n<td class=\"topaligned \"><div class=\"withmargin\">  <br /></d"
  "iv></td>\n\n<td class=\"topaligned rightcol \">\n<table><tr><td class=\"noborder\">\n                <div class=\"rec"
  "ording_errors\"><img src=\"\" width = \"16px\" alt=\"\"  /> </div>\n</td>\n<td class=\"noborder\">\n                <"
  "div class=\"recording_sd_hd\"><img src=\"\" width = \"25px\" alt=\"\"  /> </div>\n</td>\n\n<td class=\"noborder\">\n"
  "\n<div class=\"more withmargin\"><a ><span class=\"title\"></span><br /><span class=\"short\">&nbsp;</span></a></div>"
  "\n\n</td></tr></table>\n</td>\n\n\n\n\n";

// <%shared>
// </%shared>

// <%config>
// </%config>

_component_::_component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl)
  : EcppComponent(ci, um, cl),
    channel_selection(*this, "channel_selection"),
    rec_item_file(*this, "rec_item_file")
{
  // <%init>
  // </%init>
}

_component_::~_component_()
{
  // <%cleanup>
  // </%cleanup>
}

template <typename T>
inline void _tnt_ignore_unused(const T&) { }

unsigned _component_::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule " << qparam.getUrl());

  tnt::DataChunks _tntChunks(rawData);

  // <%args>
int channel = qparam.get< int >("channel", ( -1));
  // </%args>

#line 62 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_SHARED_VAR(bool, logged_in, (false));   // <%session> bool logged_in(false)
  _tnt_ignore_unused<logged_in_type>(logged_in);
#line 67 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_SHARED_VAR(cChannel*, Channel, ());   // <%request> cChannel* Channel
  _tnt_ignore_unused<Channel_type>(Channel);
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_SHARED_VAR(std::string, pageTitle, ());   // <%request> std::string pageTitle
  _tnt_ignore_unused<pageTitle_type>(pageTitle);
  // <%cpp>
  reply.out() << _tntChunks[0]; // \n
  reply.out() << _tntChunks[1]; // \n
  // <%include> page_init.eh
#line 11 "page_init.eh"

try {
	reply.setHeader("Expires", "Mon, 26 Jul 1997 05:00:00 GMT");
	tnt::Savepoint spoint( reply );

  // </%include>
#line 70 "schedule.ecpp"

if (!logged_in && LiveSetup().UseAuth()) return reply.redirect("login.html");

#line 73 "schedule.ecpp"

	pageTitle = trVDR("Schedule");

bool display_pictures = !(LiveSetup().GetTvscraperImageDir().empty());
std::list<RecordingsItemPtr> recItems;
RecordingsTreePtr recordingsTree(LiveRecordingsManager()->GetRecordingsTree());

recordingsTree->addAllRecordings(recItems);
recItems.sort(RecordingsItemPtrCompare::ByDuplicates);


#if VDRVERSNUM < 20301
	cSchedulesLock schedulesLock;
	cSchedules const* schedules = cSchedules::Schedules( schedulesLock );

	ReadLock channelsLock( Channels );
	if ( !channelsLock )
		throw HtmlError( tr("Couldn't aquire access to channels, please try again later.") );
#endif

	// cChannel* Channel; (see %request above)
	if ( channel > 0 ) {
#if VDRVERSNUM >= 20301
		LOCK_CHANNELS_READ;
		Channel = (cChannel *)Channels->GetByNumber( channel );
#else
		Channel = Channels.GetByNumber( channel );
#endif
	}
	else {
#if VDRVERSNUM >= 20301
		LOCK_CHANNELS_READ;
#endif
		if (cDevice::CurrentChannel()) {
#if VDRVERSNUM >= 20301
			Channel = (cChannel *)Channels->GetByNumber(cDevice::CurrentChannel());
#else
			Channel = Channels.GetByNumber(cDevice::CurrentChannel());
#endif
		}
		else {
#if VDRVERSNUM >= 20301
			Channel = (cChannel *)Channels->Get( Channels->GetNextNormal( -1 ) );
#else
			Channel = Channels.Get( Channels.GetNextNormal( -1 ) );
#endif
		}
	}
	if ( Channel == 0 )
		throw HtmlError( tr("Couldn't find channel or no channels available. Maybe you mistyped your request?") );

	cSchedule const* Schedule;
#if VDRVERSNUM >= 20301
	{
		LOCK_SCHEDULES_READ;
		Schedule = Schedules->GetSchedule( (const cChannel *)Channel );
	}
#else
	Schedule = schedules->GetSchedule( Channel );
#endif

  // <& pageelems.doc_type ...
  { 
#line 134 "schedule.ecpp"
    tnt::QueryParams _tnt_cq0;
#line 134 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "doc_type"), request, reply, _tnt_cq0);
    // &>
  }
  reply.out() << _tntChunks[2]; // \n<html>\n\t<head>\n\t\t<title>VDR Live - 
#line 137 "schedule.ecpp"
  reply.sout() << ( pageTitle );
  reply.out() << _tntChunks[3]; // </title>\n\t\t
  // <& pageelems.stylesheets ...
  { 
#line 138 "schedule.ecpp"
    tnt::QueryParams _tnt_cq1;
#line 138 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "stylesheets"), request, reply, _tnt_cq1);
    // &>
  }
  reply.out() << _tntChunks[4]; // \n\t\t
  // <& pageelems.ajax_js ...
  { 
#line 139 "schedule.ecpp"
    tnt::QueryParams _tnt_cq2;
#line 139 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "ajax_js"), request, reply, _tnt_cq2);
    // &>
  }
  reply.out() << _tntChunks[5]; // \n\t</head>\n\t<body onload="adjustHeader()" onresize="adjustHeader()">\n\t\t
  // <& pageelems.logo ...
  { 
#line 142 "schedule.ecpp"
    tnt::QueryParams _tnt_cq3;
#line 142 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "logo"), request, reply, _tnt_cq3);
    // &>
  }
  reply.out() << _tntChunks[6]; // \n\t\t
  // <& menu ...
  { 
#line 143 "schedule.ecpp"
    tnt::QueryParams _tnt_cq4;
#line 143 "schedule.ecpp"
    _tnt_cq4.add( "active", ("schedule"));
#line 143 "schedule.ecpp"
    _tnt_cq4.add( "component", ("schedule.channel_selection"));
#line 143 "schedule.ecpp"
    callComp(tnt::Compident(std::string(), "menu"), request, reply, _tnt_cq4);
    // &>
  }
  reply.out() << _tntChunks[7]; // \n\t\t<div class="inhalt">\n
#line 145 "schedule.ecpp"

	if ( Schedule == 0 ) {

  reply.out() << _tntChunks[8]; // \t\t\t
#line 148 "schedule.ecpp"
  reply.sout() << ( tr("No schedules available for this channel") );
  reply.out() << _tntChunks[9]; // .\n
#line 149 "schedule.ecpp"

	}
	else {

  reply.out() << _tntChunks[10]; // \t\t<table class="listing" cellspacing="0" cellpadding="0">\n
#line 154 "schedule.ecpp"

		std::string current_day = "";
		const cEvent* PresentEvent = Schedule->GetPresentEvent();
		time_t now = time(NULL) - ::Setup.EPGLinger * 60;
                RecordingsItemPtr recItem;
                bool recItemFound;
#if VDRVERSNUM >= 20301
		for (const cEvent *Event = (cEvent *)Schedule->Events()->First(); Event; Event = (cEvent *)Schedule->Events()->Next(Event)) {
#else
		for (const cEvent *Event = Schedule->Events()->First(); Event; Event = Schedule->Events()->Next(Event)) {
#endif
			if (Event->EndTime() <= now && Event != PresentEvent)
				continue;

			EpgInfoPtr epgEvent = EpgEvents::CreateEpgInfo(Channel, Event);

			std::string title(epgEvent->Title());
			std::string short_description(epgEvent->ShortDescr());
			std::string description(epgEvent->LongDescr());
			std::string start(epgEvent->StartTime(tr("%I:%M %p")));
			std::string end(epgEvent->EndTime(tr("%I:%M %p")));
                        int durationMinutes = epgEvent->Duration() / 60;
                        std::string duration(durationMinutes < 0 ? "" : FormatDuration(tr("(%d:%02d)"), durationMinutes / 60, durationMinutes % 60));
			std::string day(epgEvent->StartTime(tr("%A, %b %d %Y")));
			std::string epgid = EpgEvents::EncodeDomId(Channel->GetChannelID(), Event->EventID());

			bool truncated = false;
			bool lastEventCurrentDay = false;
// scraper data
                        std::string s_title, s_episode_name, s_IMDB_ID;
                        cTvMedia s_image;
                        bool scraper_data_available = false;
                        cGetScraperOverview scraperOverview (Event, NULL, &s_title, &s_episode_name, &s_IMDB_ID, &s_image,
                          cImageLevels(eImageLevel::episodeMovie, eImageLevel::seasonMovie, eImageLevel::tvShowCollection, eImageLevel::anySeasonCollection),
                          cOrientations(eOrientation::landscape, eOrientation::portrait, eOrientation::banner) );
                        if (scraperOverview.call(LiveSetup().GetPluginScraper()) )
                          scraper_data_available = scraperOverview.m_videoType == eVideoType::movie || scraperOverview.m_videoType == eVideoType::tvShow;

                        recItemFound = searchNameDesc(recItem, recItems, title, short_description, description, epgEvent->Duration(), &scraperOverview);
			{
#if VDRVERSNUM >= 20301
				cEvent* NextEvent = (cEvent *)Schedule->Events()->Next(Event);
#else
				cEvent* NextEvent = Schedule->Events()->Next(Event);
#endif
				if (!NextEvent) {
					lastEventCurrentDay = true;
				}
				else {
					std::string nday(NextEvent->StartTime() ? FormatDateTime(tr("%A, %b %d %Y"), NextEvent->StartTime()) : "");
					lastEventCurrentDay = (day != nday);
				}
			}

			if (current_day != day) {
				if (current_day != "") {

  reply.out() << _tntChunks[11]; // \t\t\t\t<tr class="spacer">\n\t\t\t\t\t<td colspan="5"/>\n\t\t\t\t</tr>\n
#line 214 "schedule.ecpp"

				}
int col_span;
if (display_pictures) col_span = 6;
  else col_span = 5;

  reply.out() << _tntChunks[12]; // \t\t\t\t<tr class="head">\n\t\t\t\t\t<td colspan=
#line 221 "schedule.ecpp"
  reply.sout() << (col_span);
  reply.out() << _tntChunks[13]; // ><div class="boxheader"><div><div>
#line 221 "schedule.ecpp"
  reply.sout() << ( day );
  reply.out() << _tntChunks[14]; // </div></div></div></td>\n\t\t\t\t</tr>\n
#line 223 "schedule.ecpp"

				current_day = day;
			}

  reply.out() << _tntChunks[15]; // \t\t\t\t<tr>\n\t\t\t\t\t<td class="action leftcol 
#line 228 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[16]; // ">
  // <& pageelems.event_timer ...
  { 
#line 228 "schedule.ecpp"
    tnt::QueryParams _tnt_cq5;
#line 228 "schedule.ecpp"
    _tnt_cq5.add( "epgid", (epgid));
#line 228 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "event_timer"), request, reply, _tnt_cq5);
    // &>
  }
  reply.out() << _tntChunks[17]; // </td>\n\t\t\t\t\t<td class="action 
#line 229 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[18]; // ">
#line 229 "schedule.ecpp"
if (LiveFeatures<features::epgsearch>().Recent() ) { 
  reply.out() << _tntChunks[19]; // <a href="searchresults.html\?searchplain=
#line 229 "schedule.ecpp"
  reply.sout() << ( StringUrlEncode(title) );
  reply.out() << _tntChunks[20]; // "><img src="
#line 229 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", "search.png") );
  reply.out() << _tntChunks[21]; // " alt="" 
  // <& tooltip.hint ...
  { 
#line 229 "schedule.ecpp"
    tnt::QueryParams _tnt_cq6;
#line 229 "schedule.ecpp"
    _tnt_cq6.add( "text", (tr("Search for repeats.")));
#line 229 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq6);
    // &>
  }
  reply.out() << _tntChunks[22]; // ></img></a>
#line 229 "schedule.ecpp"
 } else { 
  reply.out() << _tntChunks[23]; // <img src="img/transparent.png" width="16" height="16">
#line 229 "schedule.ecpp"
 } 
  reply.out() << _tntChunks[24]; // </td>\n\t\t\t\t\t<td class="action 
#line 230 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[25]; // ">
  // <& pageelems.imdb_info_href ...
  { 
#line 230 "schedule.ecpp"
    tnt::QueryParams _tnt_cq7;
#line 230 "schedule.ecpp"
    _tnt_cq7.add( "s_IMDB_ID", (s_IMDB_ID));
#line 230 "schedule.ecpp"
    _tnt_cq7.add( "title", (title));
#line 230 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "imdb_info_href"), request, reply, _tnt_cq7);
    // &>
  }
  reply.out() << _tntChunks[26]; // </td>\n
#line 231 "schedule.ecpp"

if (display_pictures) {
  bool episodeFound = scraperOverview.m_videoType == eVideoType::tvShow && (scraperOverview.m_episodeNumber != 0 || scraperOverview.m_seasonNumber != 0);
  std::string anf = "\"";
  std::string s_duration = "";
  if (scraper_data_available) {
    s_duration = FormatDuration(tr("(%d:%02d)"), scraperOverview.m_runtime / 60, scraperOverview.m_runtime % 60);
  } else EpgEvents::PosterTvscraper(s_image, Event, NULL);

  reply.out() << _tntChunks[27]; // <td class="
#line 240 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[28]; // ">\n<div class="thumb">\n<a class="thumb" 
  // <& tooltip.display_scraper ...
  { 
#line 242 "schedule.ecpp"
    tnt::QueryParams _tnt_cq8;
#line 242 "schedule.ecpp"
    _tnt_cq8.add( "domId", (epgEvent->Id()));
#line 242 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display_scraper"), request, reply, _tnt_cq8);
    // &>
  }
  reply.out() << _tntChunks[29]; // >\n
#line 243 "schedule.ecpp"
if (s_image.path == "") {
  reply.out() << _tntChunks[30]; //   <img src="img/transparent.png" height="10px"\n
#line 245 "schedule.ecpp"
} else {
  reply.out() << _tntChunks[31]; //   <img class="thumb" src="/tvscraper/
#line 246 "schedule.ecpp"
  reply.sout() << ( s_image.path );
  reply.out() << _tntChunks[32]; // "\n
#line 247 "schedule.ecpp"
} if (scraperOverview.m_videoType == eVideoType::tvShow || scraperOverview.m_videoType == eVideoType::movie ) {
  reply.out() << _tntChunks[33]; //   title=
#line 248 "schedule.ecpp"
  reply.out() << (anf);
#line 248 "schedule.ecpp"
  reply.sout() << (s_title);
  reply.out() << _tntChunks[34]; // \n  
#line 249 "schedule.ecpp"
if (episodeFound) {
  reply.out() << _tntChunks[35]; //     <br/>S
#line 250 "schedule.ecpp"
  reply.sout() << (scraperOverview.m_seasonNumber);
  reply.out() << _tntChunks[36]; // E
#line 250 "schedule.ecpp"
  reply.sout() << (scraperOverview.m_episodeNumber);
  reply.out() << _tntChunks[37]; //  
#line 250 "schedule.ecpp"
  reply.sout() << (s_episode_name);
  reply.out() << _tntChunks[38]; // \n  
#line 251 "schedule.ecpp"
}if (scraperOverview.m_runtime) {
  reply.out() << _tntChunks[39]; //     <br/>
#line 252 "schedule.ecpp"
  reply.sout() << (s_duration);
  reply.out() << _tntChunks[40]; // \n  
#line 253 "schedule.ecpp"
 } 
#line 254 "schedule.ecpp"
  reply.out() << (anf);
  reply.out() << _tntChunks[41]; // \n
#line 255 "schedule.ecpp"
 } 
  reply.out() << _tntChunks[42]; //   />\n</a>\n</div>\n</td>\n
#line 260 "schedule.ecpp"

}

  reply.out() << _tntChunks[43]; // \n<td class="topaligned 
#line 264 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[44]; // "><div class="withmargin">
#line 264 "schedule.ecpp"
  reply.sout() << ( start );
  reply.out() << _tntChunks[45]; //  - 
#line 264 "schedule.ecpp"
  reply.sout() << ( end );
  reply.out() << _tntChunks[46]; // <br />
#line 264 "schedule.ecpp"
  reply.sout() << ( duration );
  reply.out() << _tntChunks[47]; // </div></td>\n<td class="
#line 265 "schedule.ecpp"
  if ( (Event == PresentEvent) )
    reply.sout() <<  "current" ;
  reply.out() << _tntChunks[48]; //  topaligned rightcol 
#line 265 "schedule.ecpp"
  if ( lastEventCurrentDay && ! recItemFound )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[49]; // "><div class="more withmargin">\n  <a 
  // <& tooltip.hint ...
  { 
#line 266 "schedule.ecpp"
    tnt::QueryParams _tnt_cq9;
#line 266 "schedule.ecpp"
    _tnt_cq9.add( "text", (StringEscapeAndBreak(StringWordTruncate(description, 300, truncated)) + "<br />" + tr("Click to view details.")));
#line 266 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq9);
    // &>
  }
  // <& tooltip.display ...
  { 
#line 266 "schedule.ecpp"
    tnt::QueryParams _tnt_cq10;
#line 266 "schedule.ecpp"
    _tnt_cq10.add( "domId", (epgEvent->Id()));
#line 266 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display"), request, reply, _tnt_cq10);
    // &>
  }
  reply.out() << _tntChunks[50]; // >\n     <span class="title">
#line 267 "schedule.ecpp"
  reply.sout() << ( title );
  reply.out() << _tntChunks[51]; // </span><br /><span class="short">
#line 267 "schedule.ecpp"
if (short_description.empty()) { 
  reply.out() << _tntChunks[52]; // &nbsp;
#line 267 "schedule.ecpp"
 } 
#line 267 "schedule.ecpp"
  reply.sout() << ( short_description );
  reply.out() << _tntChunks[53]; // </span>\n  </a></div>\n</td>\n\n\t\t\t\t</tr>\n
#line 272 "schedule.ecpp"

if(recItemFound) {
                  std::string duration(recItem->Duration() < 0 ? "" : FormatDuration(tr("(%d:%02d)"), recItem->Duration() / 60, recItem->Duration() % 60));
                  std::string shortDescr(recItem->RecInfo()->ShortText() ? recItem->RecInfo()->ShortText() : "");
#if VDRVERSNUM >= 20505
                  int recordingErrors = recItem->RecInfo()->Errors();
#else
                  int recordingErrors = -1;
#endif
                  std::string channelName(recItem->RecInfo()->ChannelName()  ? recItem->RecInfo()->ChannelName() : "");
                  const char *SD_HD_icon = recItem->SD_HD_icon();

                  std::string r_description(recItem->RecInfo()->Description() ? recItem->RecInfo()->Description() : "");
                  std::string hint(tr("Click to view details."));
                  if (!shortDescr.empty()) hint = shortDescr + "<br />" + hint;
                  else if (!r_description.empty()) hint = r_description + "<br />" + hint;
          std::string name(recItem->Name());
          if( *(const char *)recItem->Recording()->Folder() ) {
             name.append(" (");
             name.append( (const char *)recItem->Recording()->Folder() );
             name.append(")");
          }


  reply.out() << _tntChunks[54]; // <tr>\n 
  // <& rec_item_file ...
  { 
#line 297 "schedule.ecpp"
    tnt::QueryParams _tnt_cq11;
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "SD_HD_icon", (SD_HD_icon));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "archived", (RecordingsManager::GetArchiveDescr(recItem->Recording())));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "channelName", (channelName));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "duration", (duration));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "hint", (hint));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "id", (recItem->Id()));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "lastEventCurrentDay", (lastEventCurrentDay));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "level", (recItem->Level()));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "name", (name));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "recordingErrors", (recordingErrors));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "shortDescr", (shortDescr));
#line 297 "schedule.ecpp"
    _tnt_cq11.add( "startTime", (recItem->StartTime()));
#line 297 "schedule.ecpp"
  main().rec_item_file(request, reply, _tnt_cq11);
    // &>
  }
  reply.out() << _tntChunks[55]; // \n</tr>\n
#line 299 "schedule.ecpp"

}

  reply.out() << _tntChunks[56]; // \n
#line 303 "schedule.ecpp"

		}

  reply.out() << _tntChunks[57]; // \t\t\t</table>\n
#line 307 "schedule.ecpp"

	}

  reply.out() << _tntChunks[58]; // \t\t</div>\n\t</body>\n</html>\n
  // <%include> page_exit.eh
  reply.out() << _tntChunks[59]; // \n
#line 5 "page_exit.eh"

	spoint.commit();
} catch ( vdrlive::HtmlError const& ex ) {
	tnt::QueryParams param = qparam;
	param.add( "pageTitle", pageTitle );
	param.add( "errorMessage", ex.what() );
	callComp( "error", request, reply, param );
}

  // </%include>
  reply.out() << _tntChunks[60]; // \n
  reply.out() << _tntChunks[70]; // \n
  reply.out() << _tntChunks[71]; // \n\n
  reply.out() << _tntChunks[102]; // \n
  reply.out() << _tntChunks[103]; // \n
  reply.out() << _tntChunks[104]; // \n
  reply.out() << _tntChunks[105]; // \n
  // <%/cpp>
  return DEFAULT;
}

unsigned _component_::channel_selection_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule::channel_selection " << qparam.getUrl());
  tnt::DataChunks _tntChunks(rawData);
#line 62 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_SHARED_VAR(bool, logged_in, (false));   // <%session> bool logged_in(false)
  _tnt_ignore_unused<logged_in_type>(logged_in);
#line 67 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_SHARED_VAR(cChannel*, Channel, ());   // <%request> cChannel* Channel
  _tnt_ignore_unused<Channel_type>(Channel);
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_SHARED_VAR(std::string, pageTitle, ());   // <%request> std::string pageTitle
  _tnt_ignore_unused<pageTitle_type>(pageTitle);
  // <%cpp>
  reply.out() << _tntChunks[61]; // <form action="schedule.html" method="get" id="channels">\n   <span>\n     <label for="channel">
#line 318 "schedule.ecpp"
  reply.sout() << ( tr("Channel") );
  reply.out() << _tntChunks[62]; // :&nbsp;<span class="bold">
#line 318 "schedule.ecpp"
  reply.sout() << ( std::to_string(Channel->Number()) );
  reply.out() << _tntChunks[63]; // </span></label>\n     
  // <& channels_widget ...
  { 
#line 319 "schedule.ecpp"
    tnt::QueryParams _tnt_cq12;
#line 319 "schedule.ecpp"
    _tnt_cq12.add( "name", ("channel"));
#line 319 "schedule.ecpp"
    _tnt_cq12.add( "onchange", ("document.forms.channels.submit()"));
#line 319 "schedule.ecpp"
    _tnt_cq12.add( "selected", (Channel ? *Channel->GetChannelID().ToString() : ""));
#line 319 "schedule.ecpp"
    callComp(tnt::Compident(std::string(), "channels_widget"), request, reply, _tnt_cq12);
    // &>
  }
  reply.out() << _tntChunks[64]; // \n     
  // <& pageelems.ajax_action_href ...
  { 
#line 320 "schedule.ecpp"
    tnt::QueryParams _tnt_cq13;
#line 320 "schedule.ecpp"
    _tnt_cq13.add( "action", "switch_channel");
#line 320 "schedule.ecpp"
    _tnt_cq13.add( "alt", "");
#line 320 "schedule.ecpp"
    _tnt_cq13.add( "image", "zap.png");
#line 320 "schedule.ecpp"
    _tnt_cq13.add( "param", (Channel->GetChannelID()));
#line 320 "schedule.ecpp"
    _tnt_cq13.add( "tip", (tr("Switch to this channel.")));
#line 320 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "ajax_action_href"), request, reply, _tnt_cq13);
    // &>
  }
  reply.out() << _tntChunks[65]; // \n     
  // <& pageelems.hls_channel ...
  { 
#line 321 "schedule.ecpp"
    tnt::QueryParams _tnt_cq14;
#line 321 "schedule.ecpp"
    _tnt_cq14.add( "channelId", (Channel->GetChannelID()));
#line 321 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "hls_channel"), request, reply, _tnt_cq14);
    // &>
  }
  reply.out() << _tntChunks[66]; // \n     
  // <& pageelems.m3u_playlist_channel ...
  { 
#line 322 "schedule.ecpp"
    tnt::QueryParams _tnt_cq15;
#line 322 "schedule.ecpp"
    _tnt_cq15.add( "channelId", (Channel->GetChannelID()));
#line 322 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "pageelems", "m3u_playlist_channel"), request, reply, _tnt_cq15);
    // &>
  }
  reply.out() << _tntChunks[67]; // \n   </span>\n</form>\n<span class="sep">|</span>\n<a href="schedule.html\?channel=
#line 326 "schedule.ecpp"
  reply.sout() << ( std::max(0, ((int)Channel->Number() - 1)) );
  reply.out() << _tntChunks[68]; // ">\302\253 Prev</a>\n<span class="sep">|</span>\n<a href="schedule.html\?channel=
#line 328 "schedule.ecpp"
  reply.sout() << ( (Channel->Number() + 1) );
  reply.out() << _tntChunks[69]; // ">Next \302\273</a>\n
  // <%/cpp>
  return DEFAULT;
}

unsigned _component_::rec_item_file_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)
{
  log_trace("schedule::rec_item_file " << qparam.getUrl());
  tnt::DataChunks _tntChunks(rawData);
  // <%args>
std::string name = qparam.get< std::string >("name");
int level = qparam.get< int >("level");
std::string id = qparam.get< std::string >("id");
time_t startTime = qparam.get< time_t >("startTime");
std::string duration = qparam.get< std::string >("duration");
std::string hint = qparam.get< std::string >("hint");
std::string shortDescr = qparam.get< std::string >("shortDescr");
int recordingErrors = qparam.get< int >("recordingErrors");
std::string channelName = qparam.get< std::string >("channelName");
std::string SD_HD_icon = qparam.get< std::string >("SD_HD_icon");
std::string archived = qparam.get< std::string >("archived");
bool lastEventCurrentDay = qparam.get< bool >("lastEventCurrentDay");
  // </%args>

#line 62 "schedule.ecpp"
  typedef bool logged_in_type;
  TNT_SESSION_SHARED_VAR(bool, logged_in, (false));   // <%session> bool logged_in(false)
  _tnt_ignore_unused<logged_in_type>(logged_in);
#line 67 "schedule.ecpp"
  typedef cChannel* Channel_type;
  TNT_REQUEST_SHARED_VAR(cChannel*, Channel, ());   // <%request> cChannel* Channel
  _tnt_ignore_unused<Channel_type>(Channel);
#line 9 "page_init.eh"
  typedef std::string pageTitle_type;
  TNT_REQUEST_SHARED_VAR(std::string, pageTitle, ());   // <%request> std::string pageTitle
  _tnt_ignore_unused<pageTitle_type>(pageTitle);
  // <%cpp>
#line 348 "schedule.ecpp"

int col_span1 = 3;
bool display_pictures = !(LiveSetup().GetTvscraperImageDir().empty());
if (display_pictures) col_span1++;
 if (!archived.empty()) { col_span1 --; 
  reply.out() << _tntChunks[72]; // <td colspan=
#line 353 "schedule.ecpp"
  reply.sout() << (col_span1);
  reply.out() << _tntChunks[73]; //  style="word-wrap: normal;min-width: 10px;max-width: 70px;" class="leftcol 
#line 353 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[74]; // "> 
#line 353 "schedule.ecpp"
  reply.sout() << ( tr("Existing Recording:") );
  reply.out() << _tntChunks[75]; //   </td>\n<td class="action 
#line 354 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[76]; // "> <img src="
#line 354 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", "on_dvd.png") );
  reply.out() << _tntChunks[77]; // " alt="on_dvd" 
  // <& tooltip.hint ...
  { 
#line 354 "schedule.ecpp"
    tnt::QueryParams _tnt_cq16;
#line 354 "schedule.ecpp"
    _tnt_cq16.add( "text", (archived));
#line 354 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq16);
    // &>
  }
  reply.out() << _tntChunks[78]; //  /> </td>\n\n
#line 356 "schedule.ecpp"
 } else { 
  reply.out() << _tntChunks[79]; // <td colspan=
#line 357 "schedule.ecpp"
  reply.sout() << (col_span1);
  reply.out() << _tntChunks[80]; //  style="word-wrap: normal;min-width: 10px;max-width: 70px;" class="leftcol 
#line 357 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[81]; // "> 
#line 357 "schedule.ecpp"
  reply.sout() << ( tr("Existing Recording:") );
  reply.out() << _tntChunks[82]; //  </td>\n
#line 358 "schedule.ecpp"
 } 
  reply.out() << _tntChunks[83]; // \n<td class="topaligned 
#line 360 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[84]; // "><div class="withmargin">
#line 360 "schedule.ecpp"
  reply.sout() << ( FormatDateTime(tr("%a,"), startTime) );
  reply.out() << _tntChunks[85]; //  
#line 360 "schedule.ecpp"
  reply.sout() << ( FormatDateTime(tr("%b %d %y"), startTime) );
  reply.out() << _tntChunks[86]; //  
#line 360 "schedule.ecpp"
  reply.sout() << ( FormatDateTime(tr("%I:%M %p"), startTime) );
  reply.out() << _tntChunks[87]; // <br />
#line 360 "schedule.ecpp"
  reply.sout() << ( duration );
  reply.out() << _tntChunks[88]; // </div></td>\n\n<td class="topaligned rightcol 
#line 362 "schedule.ecpp"
  if ( lastEventCurrentDay )
    reply.sout() <<  "bottomrow" ;
  reply.out() << _tntChunks[89]; // ">\n
#line 363 "schedule.ecpp"

#if VDRVERSNUM >= 20505
std::string recording_errors_icon;
std::string recordingErrorsStr;

if (recordingErrors == 0) {
  recording_errors_icon = "NoRecordingErrors.png";
  recordingErrorsStr = tr("No recording errors");
}
if (recordingErrors == -1) {
  recording_errors_icon = "NotCheckedForRecordingErrors.png";
  recordingErrorsStr = tr("Recording errors unknown") ;
}
if (recordingErrors >   0) {
  recording_errors_icon = "RecordingErrors.png";
  recordingErrorsStr = tr("Number of recording errors:");
  recordingErrorsStr += " " + std::to_string(recordingErrors);
}

  reply.out() << _tntChunks[90]; // <table><tr><td class="noborder">\n                <div class="recording_errors"><img src="
#line 383 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", recording_errors_icon) );
  reply.out() << _tntChunks[91]; // " width = "16px" alt="" 
  // <& tooltip.hint ...
  { 
#line 383 "schedule.ecpp"
    tnt::QueryParams _tnt_cq17;
#line 383 "schedule.ecpp"
    _tnt_cq17.add( "text", (recordingErrorsStr));
#line 383 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq17);
    // &>
  }
  reply.out() << _tntChunks[92]; //  /> </div>\n</td>\n<td class="noborder">\n                <div class="recording_sd_hd"><img src="
#line 386 "schedule.ecpp"
  reply.sout() << ( LiveSetup().GetThemedLink("img", SD_HD_icon) );
  reply.out() << _tntChunks[93]; // " width = "25px" alt="" 
  // <& tooltip.hint ...
  { 
#line 386 "schedule.ecpp"
    tnt::QueryParams _tnt_cq18;
#line 386 "schedule.ecpp"
    _tnt_cq18.add( "text", (channelName));
#line 386 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq18);
    // &>
  }
  reply.out() << _tntChunks[94]; //  /> </div>\n</td>\n\n<td class="noborder">\n
#line 390 "schedule.ecpp"

#endif

  reply.out() << _tntChunks[95]; // \n<div class="more withmargin"><a 
  // <& tooltip.hint ...
  { 
#line 394 "schedule.ecpp"
    tnt::QueryParams _tnt_cq19;
#line 394 "schedule.ecpp"
    _tnt_cq19.add( "text", (hint));
#line 394 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "hint"), request, reply, _tnt_cq19);
    // &>
  }
  // <& tooltip.display ...
  { 
#line 394 "schedule.ecpp"
    tnt::QueryParams _tnt_cq20;
#line 394 "schedule.ecpp"
    _tnt_cq20.add( "domId", (id));
#line 394 "schedule.ecpp"
    callComp(tnt::Subcompident(std::string(), "tooltip", "display"), request, reply, _tnt_cq20);
    // &>
  }
  reply.out() << _tntChunks[96]; // ><span class="title">
#line 394 "schedule.ecpp"
  reply.sout() << ( name );
  reply.out() << _tntChunks[97]; // </span><br /><span class="short">
#line 394 "schedule.ecpp"
if (shortDescr.empty()) { 
  reply.out() << _tntChunks[98]; // &nbsp;
#line 394 "schedule.ecpp"
 } 
#line 394 "schedule.ecpp"
  reply.sout() << ( shortDescr );
  reply.out() << _tntChunks[99]; // </span></a></div>\n\n
#line 396 "schedule.ecpp"

#if VDRVERSNUM >= 20505

  reply.out() << _tntChunks[100]; // </td></tr></table>\n
#line 400 "schedule.ecpp"

#endif

  reply.out() << _tntChunks[101]; // </td>\n
  // <%/cpp>
  return DEFAULT;
}

} // namespace
